@@ -2,12 +2,12 @@ import io
 import multiprocessing
 import struct
 from concurrent.futures import ThreadPoolExecutor
-from math import ceil, log2
 from dataclasses import dataclass
+from math import ceil, log2
 from operator import attrgetter
 from queue import Queue, SimpleQueue
 from threading import Thread
-from typing import List, Union, Dict, Optional, Tuple, Iterator
+from typing import Dict, Iterator, List, Optional, Tuple, Union
 
 try:
     import requests
@@ -25,11 +25,11 @@ except ModuleNotFoundError:
 
 import numpy as np
 
+from .compression import DecompressionSelection
 from .errors import LaspyException, LazError
 from .header import LasHeader
 from .point.record import PackedPointRecord, ScaleAwarePointRecord
 from .vlrs.known import BaseKnownVLR
-from .compression import DecompressionSelection
 
 DEFAULT_HTTP_WORKERS_NUM = multiprocessing.cpu_count() * 5
 
@@ -278,7 +278,7 @@ class Entry:
         return entry
 
     def __repr__(self) -> str:
-        return f"Entry(key={self.key}, offset={self.offset}, byte_size={self.byte_size}, point_count={self.point_count}"
+        return f"Entry(key={self.key}, offset={self.offset}, byte_size={self.byte_size}, point_count={self.point_count})"
 
 
 class HierarchyPage:
@@ -309,6 +309,7 @@ class CopcHierarchyVlr(BaseKnownVLR):
     """
 
     def __init__(self) -> None:
+        super().__init__()
         self.data: bytes = b""
         self.root_page = HierarchyPage()
 
@@ -403,6 +404,7 @@ def load_octree_for_query(
             page = HierarchyPage.from_bytes(page_bytes)
             hierarchy_page.entries.update(page.entries)
             nodes_to_load.insert(0, current_node)
+            continue
         elif entry.point_count != 0:
             current_node.offset = entry.offset
             current_node.byte_size = entry.byte_size
