@@ -4,20 +4,20 @@ import logging
 import struct
 import typing
 from datetime import date, timedelta
-from typing import NamedTuple, BinaryIO, Optional, List, Union, Iterable
+from typing import BinaryIO, Iterable, List, NamedTuple, Optional, Union
 from uuid import UUID
 
 import numpy as np
 
-from . import extradims
-from .compression import (
+from . import __version__, extradims
+from ._compression.format import (
     compressed_id_to_uncompressed,
     is_point_format_compressed,
     uncompressed_id_to_compressed,
 )
 from .errors import LaspyException
 from .point import dims
-from .point.format import PointFormat, ExtraBytesParams
+from .point.format import ExtraBytesParams, PointFormat
 from .point.record import PackedPointRecord
 from .utils import read_string, write_string
 from .vlrs import VLR
@@ -25,12 +25,11 @@ from .vlrs.geotiff import create_geotiff_projection_vlrs
 from .vlrs.known import (
     ExtraBytesStruct,
     ExtraBytesVlr,
-    WktCoordinateSystemVlr,
-    GeoKeyDirectoryVlr,
     GeoAsciiParamsVlr,
+    GeoKeyDirectoryVlr,
+    WktCoordinateSystemVlr,
 )
 from .vlrs.vlrlist import VLRList
-from . import __version__
 
 logger = logging.getLogger(__name__)
 
@@ -218,7 +217,7 @@ class LasHeader:
         #: Initialized to 'laspy'
         self.generating_software: Union[str, bytes] = DEFAULT_GENERATING_SOFTWARE
         self._point_format: PointFormat = point_format
-        #: Day the file was created, initialized to date.today()
+        #: Day the file was created, initialized to date.today
         self.creation_date: Optional[date] = date.today()
         #: The number of points in the file
         self.point_count: int = 0
@@ -467,8 +466,6 @@ class LasHeader:
         self.point_format = point_format
 
     def partial_reset(self) -> None:
-        self.creation_date = date.today()
-
         f64info = np.finfo(np.float64)
         self.maxs = np.ones(3, dtype=np.float64) * f64info.min
         self.mins = np.ones(3, dtype=np.float64) * f64info.max
@@ -806,12 +803,25 @@ class LasHeader:
         stream.write(vlr_bytes)
         stream.write(self.extra_vlr_bytes)
 
-    def parse_crs(self) -> Optional["pyproj.CRS"]:
+    def parse_crs(self, prefer_wkt=True) -> Optional["pyproj.CRS"]:
         """
         Method to parse OGC WKT or GeoTiff VLR keys into a pyproj CRS object
 
+        Returns None if no CRS VLR is present, or if the CRS specified
+        in the VLRS is not understood.
+
+
+        Parameters
+        ----------
+        prefer_wkt: Optional, default True,
+            If True the WKT VLR will be preferred in case
+            both the WKT and Geotiff VLR are present
+
         .. warning::
             This requires `pyproj`.
+
+        .. versionadded:: 2.5
+            The ``prefer_wkt`` parameters.
         """
 
         geo_vlr = self._vlrs.get_by_id("LASF_Projection")
@@ -819,13 +829,26 @@ class LasHeader:
         if self.evlrs is not None:
             geo_vlr.extend(self.evlrs.get_by_id("LASF_Projection"))
 
+        parsed_crs = {}
         for rec in geo_vlr:
             if isinstance(rec, (WktCoordinateSystemVlr, GeoKeyDirectoryVlr)):
                 crs = rec.parse_crs()
                 if crs is not None:
-                    return crs
+                    parsed_crs[type(rec)] = crs
 
-        return None
+        # Could not parse anything / there was nothing to parse
+        if not parsed_crs:
+            return None
+
+        if prefer_wkt:
+            preferred, other = WktCoordinateSystemVlr, GeoKeyDirectoryVlr
+        else:
+            preferred, other = GeoKeyDirectoryVlr, WktCoordinateSystemVlr
+
+        try:
+            return parsed_crs[preferred]
+        except KeyError:
+            return parsed_crs[other]
 
     def read_evlrs(self, stream):
         """
